function [pv] = ActHSmean95ci(dvar2,dvar3,dvar4,loadsteps,varname,units)
%ACTHSMEAN95CI Function to calculate mean and 95 CI using ttest
%  
% Richie Gill
% University of Bath
% July 2019

% LS 1-5 = Act1, 6-10 = Act2, 11-15 = Act3
for i=1:15
    LoadStep(i,1) = i;
    ii = find(loadsteps==i);
    if i<6
        offset=1;
    elseif i<11
        offset=6;
    else
        offset=11;
    end
    % hs2
    [ym,neg,pos,p] = smean95ci(dvar2(ii));
    xh2(i)=2+(i-offset)*0.1;
    yh2(i)=ym;
    neg2(i)=neg;
    pos2(i)=pos;
    p2(i)=p;
    % hs3
    [ym,neg,pos,p] = smean95ci(dvar3(ii));
    xh3(i)=3+(i-offset)*0.1;
    yh3(i)=ym;
    neg3(i)=neg;
    pos3(i)=pos;
    p3(i)=p;
    % hs4
    [ym,neg,pos,p] = smean95ci(dvar4(ii));
    xh4(i)=4+(i-offset)*0.1;
    yh4(i)=ym;
    neg4(i)=neg;
    pos4(i)=pos;
    p4(i)=p;
end


if strcmp('\delta VMS',varname)
    aa = [1.5 4.5 -400 200];
    units = 'N';
elseif strcmp('\delta VME',varname)
    aa = [1.5 4.5 -0.02 0.01];
    units = ' ';
    
else
    aa = [1.5 4.5 -0.2 0.25 ];
    units = 'mm';

end

% print by creating tables
dcha = char(948);
pm = char(177);
percen = char(37);
disp(sprintf('HS2: %s%s %s95%sCI %s',dcha,varname(end-2:end),pm,percen,units));
Mean=yh2'; CI95 = neg2';
HS2=table(LoadStep,Mean,CI95);
disp(HS2(1:15,:));

disp(sprintf('HS3: %s%s %s95%sCI %s',dcha,varname(end-2:end),pm,percen,units));
Mean=yh3'; CI95 = neg3';
HS3=table(LoadStep,Mean,CI95);
disp(HS3(1:15,:));

disp(sprintf('HS4: %s%s %s95%sCI %s',dcha,varname(end-2:end),pm,percen,units));
Mean=yh4'; CI95 = neg4';
HS4=table(LoadStep,Mean,CI95);
disp(HS4(1:15,:));


figure;
istart=[1,6,11];
iend=[5,10,15];
for j=1:3
    subplot(1,3,j);
    i1=istart(j);
    i2=iend(j);
    errorbar([xh2(i1:i2),xh3(i1:i2),xh4(i1:i2)],[yh2(i1:i2),yh3(i1:i2),yh4(i1:i2)],[neg2(i1:i2),neg3(i1:i2),neg4(i1:i2)],...
        [pos2(i1:i2),pos3(i1:i2),pos4(i1:i2)],'o');
    %aa=axis;
    %axis([1.5 4.5 aa(3:4)]);
    axis(aa);
    xlabel('Healing Stage');
    if isempty(units)
        ystr = sprintf('%s',varname);
    else
        ystr = sprintf('%s (%s)',varname,units);
    end
    ylabel(ystr);
    tstr = sprintf('ACT%d: %s',j,varname);
    title(tstr);
end

pv = [p2, p3, p4];

end

