function  [p,tbl,stats]=dstats_hs_vms_s1_s3(vtrial)
% 
% DSTATS_HS_VMS_S1_S3 function to extract data, plot VMS vs S1 and S3
%
% p = dstats_hs_vms_s1_s3(vtrial)
%
% Richie Gill
% Uni of Bath
% Oct 2019

% Establish x axis plotting variables and names of variables on y axis
devname={'TOMO';'TOKA'};
% set default loadsteps to be from 1 to 15
ls1 = 1;
ls2 = 15;

%define fatigue limit
FLIM = 180.0; % MPa
% define significance level
psig = 0.05/45;


% initialise structure, res, for storing results
HSC = {'H2S1', 'H2S2', 'H2S3', 'H3S3','H4S3'};
% typ = 1 , 2, 3, 4, 5, 6, 7, 8 relates to below variables
varnames = {'Von Mises Stress (MPa)', 'Max Pr Stress (MPa)', ...
    'Min Pr Stress (MPa)', 'Von Mises Strain', 'Max Pr Strain', ...
    'Min Pr Strain', 'IFM (mm)', 'Vert. IFM (mm)'};
% note that maxstress is [max_VM max_S1 max_S3]
%           minstress is [min_VM min_S1 min_S3]
%           maxstrain is [max_VM max_E1 max_E3]
%           minstrain is [min_VM min_E1 min_E3]
varnamsh = {'\sigma_{VM} (MPa)', '\sigma_1 (MPa)', ...
    '\sigma_3 (MPa)', '\epsilon_{VM}', '\epsilon_1', ...
    '\epsilon_3', '\deltaFG (mm)','\deltaFG_Z (mm)'};
npat = length(vtrial);

% set up y axis variables, which are essentially a row with each TOMO
% loadstep result listed first followed by TOKA
% first list plate stresses, then strains, then fracture gap closing, doing
% HS 2, 3, 4 for SC3, first for HS=2 ************************HS=2
xof = [0 0.2];
sc = 3; % screw config
for hs=2:4
y = [];
vms = []; % max von mises stress
s1 = [];  % max s1
s3 = []; % fracture gap closing
yi = 1; % index variable
for dev=1:2
    %dev = 1;% device, 1=TOMO, 2=TOKA
    for pat=1:npat
        if isempty(vtrial(pat).dev) || isempty(vtrial(pat).dev(dev).sc) || length(vtrial(pat).dev(dev).sc(sc).hs) < hs
            % skip this patient, no data
            steps = ls1:ls2;
            y1 =yi+(ls2-ls1);
            x(yi:y1)=steps+xof(dev);
            g(yi:y1)=dev;
            p(yi:y1)=pat;
            vms(yi:y1)=nan(1,length(steps));
            s1(yi:y1)=nan(1,length(steps));
            s3(yi:y1)=nan(1,length(steps));
            y(yi:y1)=nan(1,length(steps));
            yi =y1+1;
        else
            % go through each loadstep
            nsteps = length(vtrial(pat).dev(dev).sc(sc).hs(hs).lstep);
            for lstep=1:nsteps
                % plate Von Mises Stress
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            vms(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(1);
                            s1(yi)  = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(2);
                            s3(yi)  = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).minstress(3);
                        else
                            vms(yi) = NaN;
                            s1(yi) = NaN;
                            s3(yi) = NaN;
                        end
                x(yi) = lstep+xof(dev);
                g(yi) = dev;
                p(yi) = pat;
                yi=yi+1;
            end
            if nsteps<(ls2-ls1+1)
                missing_steps = nsteps+1:ls2;
                y1 = yi+(ls2-nsteps-1);
                str = sprintf('pat=%d dev=%d hs=%d nsteps=%d yi=%d y1=%d',pat,dev,hs,nsteps,yi,y1);
                %disp(str);
                x(yi:y1)=missing_steps+xof(dev);
                g(yi:y1)=dev;
                p(yi:y1)=pat;
                vms(yi:y1)=nan(1,length(missing_steps));
                s1(yi:y1)=nan(1,length(missing_steps));
                s3(yi:y1)=nan(1,length(missing_steps));
                yi =y1+1;
            end
        end
    end % pat loop
end % dev loop
switch hs
    case 2
        vmsh2=vms'; 
        s1h2=s1'; 
        s3h2=s3'; 
        xh2=x'; x = [];
        gh2=g'; g = [];
        ph2=p'; p = [];
        hs2=ones(size(xh2))*2;
    case 3
        vmsh3=vms'; 
        s1h3=s1'; 
        s3h3=s3'; 
        %yh3=y'; y = [];
        xh3=x'; x = [];
        gh3=g'; g = [];
        ph3=p'; p = [];
        hs3=ones(size(xh3))*3;
    case 4
        vmsh4=vms'; 
        s1h4=s1'; 
        s3h4=s3'; 
        xh4=x'; x = [];
        gh4=g'; g = [];
        ph4=p'; p = [];
        hs4=ones(size(xh4))*4;
end
yi=1;
        
end %hs loop

n = length(xh2);


% figure;
% % HS2 plot VMS versus S1, and VMS versus S3
% subplot(231);
% plot(vmsh2(1:n/2),s1h2(1:n/2),'r*');
% hold on;
% plot(vmsh2(1:n/2),s3h2(1:n/2),'go');
% axis equal;
% xlabel('Von Mises (MPa)');
% ylabel('S1/S3 (MPa)');
% title('ARM A Generic: HS2');
% 
% subplot(232);
% plot(vmsh3(1:n/2),s1h3(1:n/2),'r*');
% hold on;
% plot(vmsh3(1:n/2),s3h3(1:n/2),'go');
% axis equal;
% xlabel('Von Mises (MPa)');
% ylabel('S1/S3 (MPa)');
% title('ARM A Generic: HS3');
% 
% subplot(233);
% plot(vmsh4(1:n/2),s1h4(1:n/2),'r*');
% hold on;
% plot(vmsh4(1:n/2),s3h4(1:n/2),'go');
% axis equal;
% xlabel('Von Mises (MPa)');
% ylabel('S1/S3 (MPa)');
% title('ARM A Generic: HS4');
% 
% subplot(234);
% plot(vmsh2(1+n/2:n),s1h2(1+n/2:n),'r*');
% hold on;
% plot(vmsh2(1+n/2:n),s3h2(1+n/2:n),'go');
% axis equal;
% xlabel('Von Mises (MPa)');
% ylabel('S1/S3 (MPa)');
% title('ARM B Personalised: HS2');
% 
% subplot(235);
% plot(vmsh3(1+n/2:n),s1h3(1+n/2:n),'r*');
% hold on;
% plot(vmsh3(1+n/2:n),s3h3(1+n/2:n),'go');
% axis equal;
% xlabel('Von Mises (MPa)');
% ylabel('S1/S3 (MPa)');
% title('ARM B Personalised: HS3');
% 
% subplot(236);
% plot(vmsh4(1+n/2:n),s1h4(1+n/2:n),'r*');
% hold on;
% plot(vmsh4(1+n/2:n),s3h4(1+n/2:n),'go');
% axis equal;
% xlabel('Von Mises (MPa)');
% ylabel('S1/S3 (MPa)');
% title('ARM B Personalised: HS4');

bplt=1;
if bplt
    figure;
    % add path for boxplot2 function
    pth = '../boxplot2-pkg/';
    addpath(fullfile(pth, 'boxplot2'));
    addpath(fullfile(pth, 'minmax'));
    %bcol = {'b','r','y'};
    bcol = [ 0, 0.4470, 0.7410; ...
        0.8500, 0.3250, 0.0980; ...
        0.4660, 0.6740, 0.1880];
    lstp =1:15;
    % TOMO HS2 boxplots per loadstep
    subplot(231);
    YY = lstep_ord(xh2(1:n/2),vmsh2(1:n/2), s1h2(1:n/2), s3h2(1:n/2));
    csvwrite('GENERIC_HS2_VMS.csv',YY(:,1,:));
    csvwrite('GENERIC_HS2_S1.csv',YY(:,2,:));
    csvwrite('GENERIC_HS2_S3.csv',YY(:,3,:));
    h=boxplot2(YY,lstp);
    % Alter linestyle and color
    for ii = 1:3
        structfun(@(x) set(x(ii,:), 'color', bcol(ii,:),'markeredgecolor', bcol(ii,:)), h);
    end
    set([h.lwhis h.uwhis], 'linestyle', '-');
    set(h.out, 'marker', '.');
    title('ARM A Generic: HS2');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
%    legend('Von Mises','S_1','|S_3|');
    legend({'Von Mises','S_1','|S_3|'}, 'FontSize',7);
    
    % TOMO HS3 boxplots per loadstep
    subplot(232);
    YY = lstep_ord(xh3(1:n/2),vmsh3(1:n/2), s1h3(1:n/2), s3h3(1:n/2));
    csvwrite('GENERIC_HS3_VMS.csv',YY(:,1,:));
    csvwrite('GENERIC_HS3_S1.csv',YY(:,2,:));
    csvwrite('GENERIC_HS3_S3.csv',YY(:,3,:));
    h=boxplot2(YY,lstp);
    % Alter linestyle and color
    for ii = 1:3
        structfun(@(x) set(x(ii,:), 'color', bcol(ii,:),'markeredgecolor', bcol(ii,:)), h);
    end
    set([h.lwhis h.uwhis], 'linestyle', '-');
    set(h.out, 'marker', '.');
    title('ARM A Generic: HS3');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
    legend({'Von Mises','S_1','|S_3|'}, 'FontSize',7);
    
    % TOMO HS4 boxplots per loadstep
    subplot(233);
    YY = lstep_ord(xh4(1:n/2),vmsh4(1:n/2), s1h4(1:n/2), s3h4(1:n/2));
    csvwrite('GENERIC_HS4_VMS.csv',YY(:,1,:));
    csvwrite('GENERIC_HS4_S1.csv',YY(:,2,:));
    csvwrite('GENERIC_HS4_S3.csv',YY(:,3,:));
    h=boxplot2(YY,lstp);
    % Alter linestyle and color
    for ii = 1:3
        structfun(@(x) set(x(ii,:), 'color', bcol(ii,:),'markeredgecolor', bcol(ii,:)), h);
    end
    set([h.lwhis h.uwhis], 'linestyle', '-');
    set(h.out, 'marker', '.');
    title('ARM A Generic: HS4');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
    legend({'Von Mises','S_1','|S_3|'}, 'FontSize',7);
    
    % TOKA HS2 boxplots per loadstep
    subplot(234);
    YY = lstep_ord(xh2(1:n/2),vmsh2(1+n/2:n), s1h2(1+n/2:n), s3h2(1+n/2:n));
    csvwrite('PERSONALISED_HS2_VMS.csv',YY(:,1,:));
    csvwrite('PERSONALISED_HS2_S1.csv',YY(:,2,:));
    csvwrite('PERSONALISED_HS2_S3.csv',YY(:,3,:));


    h=boxplot2(YY,lstp);
    % Alter linestyle and color
    for ii = 1:3
        structfun(@(x) set(x(ii,:), 'color', bcol(ii,:),'markeredgecolor', bcol(ii,:)), h);
    end
    set([h.lwhis h.uwhis], 'linestyle', '-');
    set(h.out, 'marker', '.');
    title('ARM B Personalised: HS2');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
    legend({'Von Mises','S_1','|S_3|'}, 'FontSize',7);
    
    % TOKA HS3 boxplots per loadstep
    subplot(235);
    YY = lstep_ord(xh3(1:n/2),vmsh3(1+n/2:n), s1h3(1+n/2:n), s3h3(1+n/2:n));
    csvwrite('PERSONALISED_HS3_VMS.csv',YY(:,1,:));
    csvwrite('PERSONALISED_HS3_S1.csv',YY(:,2,:));
    csvwrite('PERSONALISED_HS3_S3.csv',YY(:,3,:));
    h=boxplot2(YY,lstp);
    % Alter linestyle and color
    for ii = 1:3
        structfun(@(x) set(x(ii,:), 'color', bcol(ii,:),'markeredgecolor', bcol(ii,:)), h);
    end
    set([h.lwhis h.uwhis], 'linestyle', '-');
    set(h.out, 'marker', '.');
    title('ARM B Personalised: HS3');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
    legend({'Von Mises','S_1','|S_3|'}, 'FontSize',7);
    
    % TOKA HS4 boxplots per loadstep
    subplot(236);
    YY = lstep_ord(xh4(1:n/2),vmsh4(1+n/2:n), s1h4(1+n/2:n), s3h4(1+n/2:n));
    csvwrite('PERSONALISED_HS4_VMS.csv',YY(:,1,:));
    csvwrite('PERSONALISED_HS4_S1.csv',YY(:,2,:));
    csvwrite('PERSONALISED_HS4_S3.csv',YY(:,3,:));
    h=boxplot2(YY,lstp);
    % Alter linestyle and color
    for ii = 1:3
        structfun(@(x) set(x(ii,:), 'color', bcol(ii,:),'markeredgecolor', bcol(ii,:)), h);
    end
    set([h.lwhis h.uwhis], 'linestyle', '-');
    set(h.out, 'marker', '.');
    title('ARM B Personalised: HS4');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
    legend({'Von Mises','S_1','|S_3|'}, 'FontSize',7);
    
    s1 = s1h4(1+n/2:n);
    xls = xh4(1:n/2);
    kk = find(s1>180.0);
    hold on;
    for jj=1:size(kk)
        pstr = sprintf('P%d',ph4(kk(jj)));
        text(xls(kk(jj)),s1(kk(jj)),pstr,'FontSize',6);
    end
    
end % bplt

end % END of function


function YY=lstep_ord(X,vm,s1,s3)

    Y = [vm, s1, abs(s3)];
    for i=1:15 % for each loadstep find indices
        j = find(X==i);
        YY(i,1,:) = Y(j,1);
        YY(i,2,:) = Y(j,2);
        YY(i,3,:) = Y(j,3);
    end % loadstep forloop

end % bcplt