function  [p,tbl,stats]=dstats_hs_vtrial_TOMO_TOKA(vtrial)
% 
% DSTATS_HS_VTRIAL function to extract data, calc differences to account
% for pairing, to look at the 3 healing stages (HS) for screw config (SC)3,
% plots means and 95% confidence intervals
%
% p = dstats_hs_vtrial(vtrial)
%
% Richie Gill
% Uni of Bath
% Sept 2019

% Establish x axis plotting variables and names of variables on y axis
devname={'TOMO';'TOKA'};
% set default loadsteps to be from 1 to 15
ls1 = 1;
ls2 = 15;

%define fatigue limit
FLIM = 180.0; % MPa
% define significance level
psig = 0.05/45;


% initialise structure, res, for storing results
HSC = {'H2S1', 'H2S2', 'H2S3', 'H3S3','H4S3'};
% typ = 1 , 2, 3, 4, 5, 6, 7, 8 relates to below variables
varnames = {'Von Mises Stress (MPa)', 'Max Pr Stress (MPa)', ...
    'Min Pr Stress (MPa)', 'Von Mises Strain', 'Max Pr Strain', ...
    'Min Pr Strain', 'IFM (mm)', 'Vert. IFM (mm)'};
% note that maxstress is [max_VM max_S1 max_S3]
%           minstress is [min_VM min_S1 min_S3]
%           maxstrain is [max_VM max_E1 max_E3]
%           minstrain is [min_VM min_E1 min_E3]
varnamsh = {'\sigma_{VM} (MPa)', '\sigma_1 (MPa)', ...
    '\sigma_3 (MPa)', '\epsilon_{VM}', '\epsilon_1', ...
    '\epsilon_3', '\deltaFG (mm)','\deltaFG_Z (mm)'};
npat = length(vtrial);

% set up y axis variables, which are essentially a row with each TOMO
% loadstep result listed first followed by TOKA
% first list plate stresses, then strains, then fracture gap closing, doing
% HS 2, 3, 4 for SC3, first for HS=2 ************************HS=2
xof = [0 0.2];
sc = 3; % screw config
for hs=2:4
y = [];
vms = []; % von mises stress
vme = []; % von mises strain, epsilon
fgc = []; % fracture gap closing
yi = 1; % index variable
for dev=1:2
    %dev = 1;% device, 1=TOMO, 2=TOKA
    for pat=1:npat
        if isempty(vtrial(pat).dev) || isempty(vtrial(pat).dev(dev).sc) || length(vtrial(pat).dev(dev).sc(sc).hs) < hs
            % skip this patient, no data
            steps = ls1:ls2;
            y1 =yi+(ls2-ls1);
            x(yi:y1)=steps+xof(dev);
            g(yi:y1)=dev;
            p(yi:y1)=pat;
            vms(yi:y1)=nan(1,length(steps));
            vme(yi:y1)=nan(1,length(steps));
            fgc(yi:y1)=nan(1,length(steps));
            y(yi:y1)=nan(1,length(steps));
            yi =y1+1;
        else
            % go through each loadstep
            nsteps = length(vtrial(pat).dev(dev).sc(sc).hs(hs).lstep);
            for lstep=1:nsteps
                % plate Von Mises Stress
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            vms(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(1);
                        else
                            vms(yi) = NaN;
                        end
                % bone Von mises strain
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            vme(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstrain(1);
                        else
                            vme(yi) = NaN;
                        end
                 % gap closing
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).frxdisp == 1)
                            fgc(yi) =  norm( vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp ...
                                - vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp);
                           %if yi>285 && yi<285+15 && hs==2
                           %      str = sprintf('yi:%d Pat:%d Dev:%d step:%d Prox = %10.3g %10.3g %10.3g, Dist = %10.3g %10.3g %10.3g, gap = %10.3g\n', ...
 			   %		yi,pat,dev,lstep,vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp,...
                           %             vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp, y(yi));
			   %	disp(str);
                           % end
                        else
                            fgc(yi) = NaN;
                        end
                x(yi) = lstep+xof(dev);
                g(yi) = dev;
                p(yi) = pat;
                yi=yi+1;
            end
            if nsteps<(ls2-ls1+1)
                missing_steps = nsteps+1:ls2;
                y1 = yi+(ls2-nsteps-1);
                str = sprintf('pat=%d dev=%d hs=%d nsteps=%d yi=%d y1=%d',pat,dev,hs,nsteps,yi,y1);
                %disp(str);
                x(yi:y1)=missing_steps+xof(dev);
                g(yi:y1)=dev;
                p(yi:y1)=pat;
                vms(yi:y1)=nan(1,length(missing_steps));
                vme(yi:y1)=nan(1,length(missing_steps));
                fgc(yi:y1)=nan(1,length(missing_steps));
                yi =y1+1;
            end
        end
    end % pat loop
end % dev loop
switch hs
    case 2
        vmsh2=vms'; 
        vmeh2=vme'; 
        fgch2=fgc'; 
        xh2=x'; x = [];
        gh2=g'; g = [];
        ph2=p'; p = [];
        hs2=ones(size(xh2))*2;
    case 3
        vmsh3=vms'; 
        vmeh3=vme'; 
        fgch3=fgc'; 
        %yh3=y'; y = [];
        xh3=x'; x = [];
        gh3=g'; g = [];
        ph3=p'; p = [];
        hs3=ones(size(xh3))*3;
    case 4
        vmsh4=vms'; 
        vmeh4=vme'; 
        fgch4=fgc'; 
        xh4=x'; x = [];
        gh4=g'; g = [];
        ph4=p'; p = [];
        hs4=ones(size(xh4))*4;
end
yi=1;
        
end %hs loop



% calculate differences between groups by calculating TOMO - TOKA
% HS2
    n = length(xh2);
    dvmsh2 = vmsh2(1:n/2)-vmsh2(1+n/2:n);
    dvmeh2 = vmeh2(1:n/2)-vmeh2(1+n/2:n);
    dfgch2 = fgch2(1:n/2)-fgch2(1+n/2:n);
% HS3
    dvmsh3 = vmsh3(1:n/2)-vmsh3(1+n/2:n);
    dvmeh3 = vmeh3(1:n/2)-vmeh3(1+n/2:n);
    dfgch3 = fgch3(1:n/2)-fgch3(1+n/2:n);
% HS4
    dvmsh4 = vmsh4(1:n/2)-vmsh4(1+n/2:n);
    dvmeh4 = vmeh4(1:n/2)-vmeh4(1+n/2:n);
    dfgch4 = fgch4(1:n/2)-fgch4(1+n/2:n);

    
% display values of means for TOMO
% disp('TOMO VMS H2');
% ls_mean95ci(vmsh2(1:n/2),xh2(1:n/2),2);    
% disp('TOMO VMS H3');
% ls_mean95ci(vmsh3(1:n/2),xh3(1:n/2),2);    
% disp('TOMO VMS H4');
% ls_mean95ci(vmsh4(1:n/2),xh4(1:n/2),2);    

% display values of means for TOKA
% disp('TOKA VMS H2');
% ls_mean95ci(vmsh2(1+n/2:n),xh2(1:n/2),2);    
% disp('TOKA VMS H3');
% ls_mean95ci(vmsh3(1+n/2:n),xh3(1:n/2),2);    
% disp('TOKA VMS H4');
% ls_mean95ci(vmsh4(1+n/2:n),xh4(1:n/2),2);    

    
% Von Mises Stress
disp('dVMS H2');
[xx2,yy2,neg2,pos2,pv2] = ls_mean95ci(dvmsh2,xh2(1:n/2),2);
disp('dVMS H3');
[xx3,yy3,neg3,pos3,pv3] = ls_mean95ci(dvmsh3,xh3(1:n/2),3);
disp('dVMS H4');
[xx4,yy4,neg4,pos4,pv4] = ls_mean95ci(dvmsh4,xh4(1:n/2),4);

figure;
i1=[1,6,11];
i2=[5,10,15];

for j=1:3
    subplot(1,3,j);
    errorbar([xx2(i1(j):i2(j)),xx3(i1(j):i2(j)),xx4(i1(j):i2(j))],...
        [yy2(i1(j):i2(j)),yy3(i1(j):i2(j)),yy4(i1(j):i2(j))],...
        [neg2(i1(j):i2(j)),neg3(i1(j):i2(j)),neg4(i1(j):i2(j))],...
        [pos2(i1(j):i2(j)),pos3(i1(j):i2(j)),pos4(i1(j):i2(j))],'o');
    %aa=axis;
    llim = -200;
    ulim = 400;
    axis([1.5 4.5 llim ulim]);
    tstr=sprintf('Activity %d',j);
    title(tstr);
    xlabel('Healing Stage');
    ylabel('\delta VMS (MPa)');
    hold on;
    pltstar = 0;
    if pltstar
        for k=i1(j):i2(j)
            if pv2(k)<=psig
                plot(xx2(k),llim,'r*');
                str = sprintf('HS2 VMS p=%0.5g',pv2(k));
                disp(str);
            end
            if pv3(k)<=psig
                plot(xx3(k),llim,'r*');
                str = sprintf('HS3 VMS p=%0.5g',pv3(k));
                disp(str);
            end
            if pv4(k)<=psig
                plot(xx4(k),llim,'r*');
                str = sprintf('HS4 VMS p=%0.5g',pv4(k));
                disp(str);
            end
        end
    end
end

% Von Mises Strain
disp('dVME H2');
[xx2,yy2,neg2,pos2,pv2] = ls_mean95ci(dvmeh2,xh2(1:n/2),2);
disp('dVME H3');
[xx3,yy3,neg3,pos3,pv3] = ls_mean95ci(dvmeh3,xh3(1:n/2),3);
disp('dVME H4');
[xx4,yy4,neg4,pos4,pv4] = ls_mean95ci(dvmeh4,xh4(1:n/2),4);

figure;
i1=[1,6,11];
i2=[5,10,15];

for j=1:3
    subplot(1,3,j);
    errorbar([xx2(i1(j):i2(j)),xx3(i1(j):i2(j)),xx4(i1(j):i2(j))],...
        [yy2(i1(j):i2(j)),yy3(i1(j):i2(j)),yy4(i1(j):i2(j))],...
        [neg2(i1(j):i2(j)),neg3(i1(j):i2(j)),neg4(i1(j):i2(j))],...
        [pos2(i1(j):i2(j)),pos3(i1(j):i2(j)),pos4(i1(j):i2(j))],'o');
    
    llim = -0.02;
    axis([1.5 4.5 llim 0.01]);
    tstr=sprintf('Activity %d',j);
    title(tstr);
    xlabel('Healing Stage');
    ylabel('\delta VME');
    hold on;
    for k=i1(j):i2(j)
        if pv2(k)<=psig
            plot(xx2(k),llim,'r*');
        end
        if pv3(k)<=psig
            plot(xx3(k),llim,'r*');
        end
        if pv4(k)<=psig
            plot(xx4(k),llim,'r*');
        end
    end
end

% delta IFM
disp('dIFM H2');
[xx2,yy2,neg2,pos2,pv2] = ls_mean95ci(dfgch2,xh2(1:n/2),2);
disp('dIFM H3');
[xx3,yy3,neg3,pos3,pv3] = ls_mean95ci(dfgch3,xh3(1:n/2),3);
disp('dIFM H4');
[xx4,yy4,neg4,pos4,pv4] = ls_mean95ci(dfgch4,xh4(1:n/2),4);

figure;
i1=[1,6,11];
i2=[5,10,15];

for j=1:3
    subplot(1,3,j);
    errorbar([xx2(i1(j):i2(j)),xx3(i1(j):i2(j)),xx4(i1(j):i2(j))],...
        [yy2(i1(j):i2(j)),yy3(i1(j):i2(j)),yy4(i1(j):i2(j))],...
        [neg2(i1(j):i2(j)),neg3(i1(j):i2(j)),neg4(i1(j):i2(j))],...
        [pos2(i1(j):i2(j)),pos3(i1(j):i2(j)),pos4(i1(j):i2(j))],'o');
    %aa=axis;
    llim = -0.2;
    axis([1.5 4.5 llim 0.25]);
    tstr=sprintf('Activity %d',j);
    title(tstr);
    xlabel('Healing Stage');
    ylabel('\delta IFM (mm)');
    hold on;
    for k=i1(j):i2(j)
        if pv2(k)<=psig
            plot(xx2(k),llim,'r*');
        end
        if pv3(k)<=psig
            plot(xx3(k),llim,'r*');
        end
        if pv4(k)<=psig
            plot(xx4(k),llim,'r*');
        end
    end
end

% create plot of means for each arm
plotmeans = 1;

if plotmeans

% plot means & 95%CIs
% Von Mises Stress for TOMO
    n = length(xh2);
    [ls1,mvmss1,neg1,pos1,pv1] = scls_mean95ci(vmsh2(1:n/2),xh2(1:n/2),1);
[ls2,mvmss2,neg2,pos2,pv2] = scls_mean95ci(vmsh3(1:n/2),xh3(1:n/2),2);
[ls3,mvmss3,neg3,pos3,pv3] = scls_mean95ci(vmsh4(1:n/2),xh4(1:n/2),3);

% do ANOVA for TOMO comparing all three HS for each loadstep
disp('TOMO:VMS Loadstep p Sig HS2 HS3 HS4');
p=sc_anova(vmsh2(1:n/2),xh2(1:n/2),vmsh3(1:n/2),xh3(1:n/2),vmsh4(1:n/2),xh4(1:n/2));
disp('TOMO:VME Loadstep p Sig HS2 HS3 HS4');
p=sc_anova(vmeh2(1:n/2),xh2(1:n/2),vmeh3(1:n/2),xh3(1:n/2),vmeh4(1:n/2),xh4(1:n/2));
disp('TOMO:IFM Loadstep p Sig HS2 HS3 HS4');
p=sc_anova(fgch2(1:n/2),xh2(1:n/2),fgch3(1:n/2),xh3(1:n/2),fgch4(1:n/2),xh4(1:n/2));

% calc median & iqr for each activity & HS
disp('TOMO:VMS Activity HS2 HS3 HS4');
p=activity_median(vmsh2(1:n/2),xh2(1:n/2),vmsh3(1:n/2),xh3(1:n/2),vmsh4(1:n/2),xh4(1:n/2));
disp('TOMO:VME Activity HS2 HS3 HS4');
p=activity_median(vmeh2(1:n/2),xh2(1:n/2),vmeh3(1:n/2),xh3(1:n/2),vmeh4(1:n/2),xh4(1:n/2));
disp('TOMO:IFM Activity HS2 HS3 HS4');
p=activity_median(fgch2(1:n/2),xh2(1:n/2),fgch3(1:n/2),xh3(1:n/2),fgch4(1:n/2),xh4(1:n/2));



figure;
i1=[1,6,11];
i2=[5,10,15];

for j=1:3
    subplot(2,3,j);
    errorbar([ls1(i1(j):i2(j));ls2(i1(j):i2(j));ls3(i1(j):i2(j))]',...
        [mvmss1(i1(j):i2(j));mvmss2(i1(j):i2(j));mvmss3(i1(j):i2(j))]',...
        [neg1(i1(j):i2(j));neg2(i1(j):i2(j));neg3(i1(j):i2(j))]',...
        [pos1(i1(j):i2(j));pos2(i1(j):i2(j));pos3(i1(j):i2(j))]','o');
    %aa=axis;
    %llim = -400;
    axis([0.5+(j-1)*5 5.5+(j-1)*5 0 700]);
    tstr=sprintf('ARM A Generic: Activity %d',j);
    title(tstr);
    legend('HS2','HS3','HS4');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
end

% Von Mises for TOKA
[ls1,mvmss1,neg1,pos1,pv1] = scls_mean95ci(vmsh2(1+n/2:n),xh2(1:n/2),1);
[ls2,mvmss2,neg2,pos2,pv2] = scls_mean95ci(vmsh3(1+n/2:n),xh3(1:n/2),2);
[ls3,mvmss3,neg3,pos3,pv3] = scls_mean95ci(vmsh4(1+n/2:n),xh4(1:n/2),3);

% do ANOVA for TOKA comparing all three HS for each loadstep
disp('TOKA:VMS Loadstep p Sig HS2 HS3 HS4');
p=sc_anova(vmsh2(1+n/2:n),xh2(1:n/2),vmsh3(1+n/2:n),xh3(1:n/2),vmsh4(1+n/2:n),xh4(1:n/2));
disp('TOKA:VME Loadstep p Sig HS2 HS3 HS4');
p=sc_anova(vmeh2(1+n/2:n),xh2(1:n/2),vmeh3(1+n/2:n),xh3(1:n/2),vmeh4(1+n/2:n),xh4(1:n/2));
disp('TOKA:IFM Loadstep p Sig HS2 HS3 HS4');
p=sc_anova(fgch2(1+n/2:n),xh2(1:n/2),fgch3(1+n/2:n),xh3(1:n/2),fgch4(1+n/2:n),xh4(1:n/2));

% do ANOVA for TOKA comparing all three HS for each activity
disp('TOKA:VMS Activity HS2 HS3 HS4');
p=activity_median(vmsh2(1+n/2:n),xh2(1:n/2),vmsh3(1+n/2:n),xh3(1:n/2),vmsh4(1+n/2:n),xh4(1:n/2));
disp('TOKA:VME Activity HS2 HS3 HS4');
p=activity_median(vmeh2(1+n/2:n),xh2(1:n/2),vmeh3(1+n/2:n),xh3(1:n/2),vmeh4(1+n/2:n),xh4(1:n/2));
disp('TOKA:IFM Activity HS2 HS3 HS4');
p=activity_median(fgch2(1+n/2:n),xh2(1:n/2),fgch3(1+n/2:n),xh3(1:n/2),fgch4(1+n/2:n),xh4(1:n/2));


for j=1:3
    subplot(2,3,j+3);
    errorbar([ls1(i1(j):i2(j));ls2(i1(j):i2(j));ls3(i1(j):i2(j))]',...
        [mvmss1(i1(j):i2(j));mvmss2(i1(j):i2(j));mvmss3(i1(j):i2(j))]',...
        [neg1(i1(j):i2(j));neg2(i1(j):i2(j));neg3(i1(j):i2(j))]',...
        [pos1(i1(j):i2(j));pos2(i1(j):i2(j));pos3(i1(j):i2(j))]','o');
    %aa=axis;
    %llim = -400;
    axis([0.5+(j-1)*5 5.5+(j-1)*5 0 700]);
    tstr=sprintf('ARM B Personalised: Activity %d',j);
    title(tstr);
    legend('HS2','HS3','HS4');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
end

end % plotmeans

end % END of function


