function  [p,tbl,stats]=dstats_sc_vtrial(vtrial)
% 
% DSTATS_SC_VTRIAL function to extract data, calc differences to account
% for pairing, to look at the 3 screw configs (SC) for healing stage (SC)2,
% plots means and 95% confidence intervals
%
% p = dstats_hs_vtrial(vtrial)
%
% Richie Gill
% Uni of Bath
% Sept 2019

% Establish x axis plotting variables and names of variables on y axis
devname={'TOMO';'TOKA'};
% set default loadsteps to be from 1 to 15
ls1 = 1;
ls2 = 15;

%define fatigue limit
FLIM = 180.0; % MPa
% define significance level
psig = 0.05/45;

% initialise structure, res, for storing results
HSC = {'H2S1', 'H2S2', 'H2S3', 'H3S3','H4S3'};
% typ = 1 , 2, 3, 4, 5, 6, 7, 8 relates to below variables
varnames = {'Von Mises Stress (MPa)', 'Max Pr Stress (MPa)', ...
    'Min Pr Stress (MPa)', 'Von Mises Strain', 'Max Pr Strain', ...
    'Min Pr Strain', 'IFM (mm)', 'Vert. IFM (mm)'};
% note that maxstress is [max_VM max_S1 max_S3]
%           minstress is [min_VM min_S1 min_S3]
%           maxstrain is [max_VM max_E1 max_E3]
%           minstrain is [min_VM min_E1 min_E3]
varnamsh = {'\sigma_{VM} (MPa)', '\sigma_1 (MPa)', ...
    '\sigma_3 (MPa)', '\epsilon_{VM}', '\epsilon_1', ...
    '\epsilon_3', '\deltaFG (mm)','\deltaFG_Z (mm)'};
npat = length(vtrial);

% set up y axis variables, which are essentially a row with each TOMO
% loadstep result listed first followed by TOKA
% first list plate stresses, then strains, then fracture gap closing, doing
% HS 2, 3, 4 for SC3, first for HS=2 ************************HS=2
xof = [0 0.2];
hs = 2; % screw config
for sc=1:3
y = [];
vms = []; % von mises stress
vme = []; % von mises strain, epsilon
fgc = []; % fracture gap closing
yi = 1; % index variable
for dev=1:2
    %dev = 1;% device, 1=TOMO, 2=TOKA
    for pat=1:npat
        if isempty(vtrial(pat).dev) || isempty(vtrial(pat).dev(dev).sc) || length(vtrial(pat).dev(dev).sc(sc).hs) < hs
            % skip this patient, no data
            steps = ls1:ls2;
            y1 =yi+(ls2-ls1);
            x(yi:y1)=steps+xof(dev);
            g(yi:y1)=dev;
            p(yi:y1)=pat;
            vms(yi:y1)=nan(1,length(steps));
            vme(yi:y1)=nan(1,length(steps));
            fgc(yi:y1)=nan(1,length(steps));
            y(yi:y1)=nan(1,length(steps));
            yi =y1+1;
        else
            % go through each loadstep
            nsteps = length(vtrial(pat).dev(dev).sc(sc).hs(hs).lstep);
            for lstep=1:nsteps
                % plate Von Mises Stress
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            vms(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(1);
                        else
                            vms(yi) = NaN;
                        end
                % bone Von mises strain
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            vme(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstrain(1);
                        else
                            vme(yi) = NaN;
                        end
                 % gap closing
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).frxdisp == 1)
                            fgc(yi) =  norm( vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp ...
                                - vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp);
                           %if yi>285 && yi<285+15 && hs==2
                           %      str = sprintf('yi:%d Pat:%d Dev:%d step:%d Prox = %10.3g %10.3g %10.3g, Dist = %10.3g %10.3g %10.3g, gap = %10.3g\n', ...
 			   %		yi,pat,dev,lstep,vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp,...
                           %             vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp, y(yi));
			   %	disp(str);
                           % end
                        else
                            fgc(yi) = NaN;
                        end
                x(yi) = lstep+xof(dev);
                g(yi) = dev;
                p(yi) = pat;
                yi=yi+1;
            end
            if nsteps<(ls2-ls1+1)
                missing_steps = nsteps+1:ls2;
                y1 = yi+(ls2-nsteps-1);
                str = sprintf('pat=%d dev=%d hs=%d nsteps=%d yi=%d y1=%d',pat,dev,hs,nsteps,yi,y1);
                %disp(str);
                x(yi:y1)=missing_steps+xof(dev);
                g(yi:y1)=dev;
                p(yi:y1)=pat;
                vms(yi:y1)=nan(1,length(missing_steps));
                vme(yi:y1)=nan(1,length(missing_steps));
                fgc(yi:y1)=nan(1,length(missing_steps));
                yi =y1+1;
            end
        end
    end % pat loop
end % dev loop
switch sc 
    case 1
        vmss1=vms'; 
        vmes1=vme'; 
        fgcs1=fgc'; 
        xs1=x'; x = [];
        gs1=g'; g = [];
        ps1=p'; p = [];
    case 2
        vmss2=vms'; 
        vmes2=vme'; 
        fgcs2=fgc'; 
        %ys2=y'; y = [];
        xs2=x'; x = [];
        gs2=g'; g = [];
        ps2=p'; p = [];
    case 3
        vmss3=vms'; 
        vmes3=vme'; 
        fgcs3=fgc'; 
        xs3=x'; x = [];
        gs3=g'; g = [];
        ps3=p'; p = [];
end
yi=1;
        
end %sc loop

% %check load steps are consistent
% figure;
% n = length(xs1)
% plot(xs1(1:n/2),xs1(1+n/2:n),'r*');
% hold on;
% n = length(xs2)
% plot(xs2(1:n/2),xs2(1+n/2:n),'go');
% n = length(xs3)
% plot(xs3(1:n/2),xs3(1+n/2:n),'m^');

figure;
% effects of screw configuration scatter plot
% do plotting
% plot for hs=2, sc=1
subplot(131);
gscatter(xs1,vmss1,gs1);
axis([0 16 0 3000]);
xlabel('Load Step');
ylabel('Plate VMS (MPa)')
legend('TOMO','TOKA');
tstr = sprintf('VMS SC1 H2');
title(tstr);

% plot for hs=2, sc=2
subplot(132);
gscatter(xs2,vmss2,gs2);
axis([0 16 0 3000]);
xlabel('Load Step');
ylabel('Plate VMS (MPa)')
legend('TOMO','TOKA');
tstr = sprintf('VMS SC2 H2');
title(tstr);

% plot for hs=2, sc=3
subplot(133);
gscatter(xs3,vmss3,gs3);
axis([0 16 0 3000]);
xlabel('Load Step');
ylabel('Plate VMS (MPa)')
legend('TOMO','TOKA');
tstr = sprintf('VMS SC3 H2');
title(tstr);

% plot means & 95%CIs
% Von Mises Stress for TOMO
    n = length(xs1);
[ls1,mvmss1,neg1,pos1,pv1] = scls_mean95ci(vmss1(1:n/2),xs1(1:n/2),1);
[ls2,mvmss2,neg2,pos2,pv2] = scls_mean95ci(vmss2(1:n/2),xs2(1:n/2),2);
[ls3,mvmss3,neg3,pos3,pv3] = scls_mean95ci(vmss3(1:n/2),xs3(1:n/2),3);

disp('TOMO Von Mises Stress (MPa) [ mean (Lower_95%CI Upper_95%CI)]');
disp('SC1');
for i=1:length(ls1)
     fprintf('Loadstep %d: %0.5g (%0.5g %0.5g) \n',ls1(i),mvmss1(i),neg1(i),pos1(i));
end
disp('SC2');
for i=1:length(ls1)
     fprintf('Loadstep %d: %0.5g (%0.5g %0.5g) \n',ls1(i),mvmss2(i),neg2(i),pos2(i));
end
disp('SC3');
for i=1:length(ls1)
     fprintf('Loadstep %d: %0.5g (%0.5g %0.5g) \n',ls1(i),mvmss3(i),neg3(i),pos3(i));
end

% do ANOVA for TOMO comparing all three SC for each loadstep
p=sc_anova(vmss1(1:n/2),xs1(1:n/2),vmss2(1:n/2),xs2(1:n/2),vmss3(1:n/2),xs3(1:n/2));
% do ANOVA for TOMO comparing all three SC for each activity
%p=sc_act_anova(vmss1(1:n/2),xs1(1:n/2),vmss2(1:n/2),xs2(1:n/2),vmss3(1:n/2),xs3(1:n/2));

figure;
i1=[1,6,11];
i2=[5,10,15];

for j=1:3
    subplot(2,3,j);
    errorbar([ls1(i1(j):i2(j));ls2(i1(j):i2(j));ls3(i1(j):i2(j))]',...
        [mvmss1(i1(j):i2(j));mvmss2(i1(j):i2(j));mvmss3(i1(j):i2(j))]',...
        [neg1(i1(j):i2(j));neg2(i1(j):i2(j));neg3(i1(j):i2(j))]',...
        [pos1(i1(j):i2(j));pos2(i1(j):i2(j));pos3(i1(j):i2(j))]','o');
    %aa=axis;
    %llim = -400;
    axis([0.5+(j-1)*5 5.5+(j-1)*5 0 700]);
    tstr=sprintf('ARM A Generic: Activity %d',j);
    title(tstr);
    legend('SC1','SC2','SC3');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
end

% Von Mises for TOKA
[ls1,mvmss1,neg1,pos1,pv1] = scls_mean95ci(vmss1(1+n/2:n),xs1(1:n/2),1);
[ls2,mvmss2,neg2,pos2,pv2] = scls_mean95ci(vmss2(1+n/2:n),xs2(1:n/2),2);
[ls3,mvmss3,neg3,pos3,pv3] = scls_mean95ci(vmss3(1+n/2:n),xs3(1:n/2),3);

disp('---');
disp('TOKA Von Mises Stress (MPa) [ mean (Lower_95%CI Upper_95%CI)]');
disp('SC1');
for i=1:length(ls1)
     fprintf('Loadstep %d: %0.5g (%0.5g %0.5g) \n',ls1(i),mvmss1(i),neg1(i),pos1(i));
end
disp('SC2');
for i=1:length(ls1)
     fprintf('Loadstep %d: %0.5g (%0.5g %0.5g) \n',ls1(i),mvmss2(i),neg2(i),pos2(i));
end
disp('SC3');
for i=1:length(ls1)
     fprintf('Loadstep %d: %0.5g (%0.5g %0.5g) \n',ls1(i),mvmss3(i),neg3(i),pos3(i));
end

% do ANOVA for TOKA comparing all three SC for each loadstep
p=sc_anova(vmss1(1+n/2:n),xs1(1:n/2),vmss2(1+n/2:n),xs2(1:n/2),vmss3(1+n/2:n),xs3(1:n/2));
% do ANOVA for TOKA comparing all three SC for each activity
%p=sc_act_anova(vmss1(1+n/2:n),xs1(1:n/2),vmss2(1+n/2:n),xs2(1:n/2),vmss3(1+n/2:n),xs3(1:n/2));
for j=1:3
    subplot(2,3,j+3);
    errorbar([ls1(i1(j):i2(j));ls2(i1(j):i2(j));ls3(i1(j):i2(j))]',...
        [mvmss1(i1(j):i2(j));mvmss2(i1(j):i2(j));mvmss3(i1(j):i2(j))]',...
        [neg1(i1(j):i2(j));neg2(i1(j):i2(j));neg3(i1(j):i2(j))]',...
        [pos1(i1(j):i2(j));pos2(i1(j):i2(j));pos3(i1(j):i2(j))]','o');
    %aa=axis;
    %llim = -400;
    axis([0.5+(j-1)*5 5.5+(j-1)*5 0 700]);
    tstr=sprintf('ARM B Personalised: Activity %d',j);
    title(tstr);
    legend('SC1','SC2','SC3');
    xlabel('Load Step');
    ylabel('Plate Stress (MPa)');
end


return %zool

% calculate differences between groups by subtracting TOMO results from
% TOKA
    n = length(xs1);
    dvmss1 = vmss1(1+n/2:n)-vmss1(1:n/2);
    dvmes1 = vmes1(1+n/2:n)-vmes1(1:n/2);
    dfgcs1 = fgcs1(1+n/2:n)-fgcs1(1:n/2);

    n = length(xs2);
    dvmss2 = vmss2(1+n/2:n)-vmss2(1:n/2);
    dvmes2 = vmes2(1+n/2:n)-vmes2(1:n/2);
    dfgcs2 = fgcs2(1+n/2:n)-fgcs2(1:n/2);

    n = length(xs3);
    dvmss3 = vmss3(1+n/2:n)-vmss3(1:n/2);
    dvmes3 = vmes3(1+n/2:n)-vmes3(1:n/2);
    dfgcs3 = fgcs3(1+n/2:n)-fgcs3(1:n/2);    

% Von Mises Stress
[xx2,yy2,neg2,pos2,pv2] = ls_mean95ci(dvmss1,xs1(1:n/2),1);
[xx3,yy3,neg3,pos3,pv3] = ls_mean95ci(dvmss2,xs2(1:n/2),2);
[xx4,yy4,neg4,pos4,pv4] = ls_mean95ci(dvmss3,xs3(1:n/2),3);

figure;
i1=[1,6,11];
i2=[5,10,15];

for j=1:3
    subplot(1,3,j);
    errorbar([xx2(i1(j):i2(j)),xx3(i1(j):i2(j)),xx4(i1(j):i2(j))],...
        [yy2(i1(j):i2(j)),yy3(i1(j):i2(j)),yy4(i1(j):i2(j))],...
        [neg2(i1(j):i2(j)),neg3(i1(j):i2(j)),neg4(i1(j):i2(j))],...
        [pos2(i1(j):i2(j)),pos3(i1(j):i2(j)),pos4(i1(j):i2(j))],'o');
    %aa=axis;
    llim = -400;
    axis([1.5 4.5 llim 200]);
    tstr=sprintf('Activity %d',j);
    title(tstr);
    xlabel('Screw Configuration');
    ylabel('\delta VMS (MPa)');
    hold on;
    for k=i1(j):i2(j)
        if pv2(k)<0.05
            plot(xx2(k),llim,'r*');
            str = sprintf('SC1 VMS p=%0.5g',pv2(k)); 
            disp(str);
        end
        if pv3(k)<0.05
            plot(xx3(k),llim,'r*');
            str = sprintf('SC2 VMS p=%0.5g',pv3(k)); 
            disp(str);
        end
        if pv4(k)<0.05
            plot(xx4(k),llim,'r*');
            str = sprintf('SC3 VMS p=%0.5g',pv4(k)); 
            disp(str);
        end
    end
end

% Von Mises Strain
[xx2,yy2,neg2,pos2,pv2] = ls_mean95ci(dvmes1,xs1(1:n/2),1);
[xx3,yy3,neg3,pos3,pv3] = ls_mean95ci(dvmes2,xs2(1:n/2),2);
[xx4,yy4,neg4,pos4,pv4] = ls_mean95ci(dvmes3,xs3(1:n/2),3);

figure;
i1=[1,6,11];
i2=[5,10,15];

for j=1:3
    subplot(1,3,j);
    errorbar([xx2(i1(j):i2(j)),xx3(i1(j):i2(j)),xx4(i1(j):i2(j))],...
        [yy2(i1(j):i2(j)),yy3(i1(j):i2(j)),yy4(i1(j):i2(j))],...
        [neg2(i1(j):i2(j)),neg3(i1(j):i2(j)),neg4(i1(j):i2(j))],...
        [pos2(i1(j):i2(j)),pos3(i1(j):i2(j)),pos4(i1(j):i2(j))],'o');
    
    llim = -0.02;
    axis([1.5 4.5 llim 0.01]);
    tstr=sprintf('Activity %d',j);
    title(tstr);
    xlabel('Screw Configuration');
    ylabel('\delta VME');
    hold on;
    for k=i1(j):i2(j)
        if pv2(k)<0.05
            plot(xx2(k),llim,'r*');
        end
        if pv3(k)<0.05
            plot(xx3(k),llim,'r*');
        end
        if pv4(k)<0.05
            plot(xx4(k),llim,'r*');
        end
    end
end

[xx2,yy2,neg2,pos2,pv2] = ls_mean95ci(dfgcs1,xs1(1:n/2),1);
[xx3,yy3,neg3,pos3,pv3] = ls_mean95ci(dfgcs2,xs2(1:n/2),2);
[xx4,yy4,neg4,pos4,pv4] = ls_mean95ci(dfgcs3,xs3(1:n/2),3);

figure;
i1=[1,6,11];
i2=[5,10,15];

for j=1:3
    subplot(1,3,j);
    errorbar([xx2(i1(j):i2(j)),xx3(i1(j):i2(j)),xx4(i1(j):i2(j))],...
        [yy2(i1(j):i2(j)),yy3(i1(j):i2(j)),yy4(i1(j):i2(j))],...
        [neg2(i1(j):i2(j)),neg3(i1(j):i2(j)),neg4(i1(j):i2(j))],...
        [pos2(i1(j):i2(j)),pos3(i1(j):i2(j)),pos4(i1(j):i2(j))],'o');
    %aa=axis;
    llim = -0.2;
    axis([1.5 4.5 llim 0.25]);
    tstr=sprintf('Activity %d',j);
    title(tstr);
    xlabel('Screw Configuration');
    ylabel('\delta IFM (mm)');
    hold on;
    for k=i1(j):i2(j)
        if pv2(k)<0.05
            plot(xx2(k),llim,'r*');
        end
        if pv3(k)<0.05
            plot(xx3(k),llim,'r*');
        end
        if pv4(k)<0.05
            plot(xx4(k),llim,'r*');
        end
    end
end

end % END of function


