function  pltvtrial2(vtrial,ls1,ls2,typ)
% [x,y,g,p]=
% PLTVTRIAL1 function to plot data stored in vtrial
%
% Richie Gill
% Uni of Bath
% June 2019

% Establish x axis plotting variables and names of variables on y axis
devname={'TOMO';'TOKA'};
% set default loadsteps to be from 1 to 15
if nargin<3
    ls1 = 1;
    ls2 = 15;
    typ = 1;
end

if isempty(ls1)
    ls1 = 1;
end

if isempty(ls2)
    ls2 = 15;
end

%define fatigue limit
FLIM = 180.0; % MPa


% initialise structure, res, for storing results
HSC = {'H2S1', 'H2S2', 'H2S3', 'H3S3','H4S3'};
% typ = 1 , 2, 3, 4, 5, 6, 7, 8 relates to below variables
varnames = {'Von Mises Stress (MPa)', 'Max Pr Stress (MPa)', ...
    'Min Pr Stress (MPa)', 'Von Mises Strain', 'Max Pr Strain', ...
    'Min Pr Strain', 'Frac. Gap Closing (mm)', 'Vert. Frac. Gap Closing (mm)'};
% note that maxstress is [max_VM max_S1 max_S3]
%           minstress is [min_VM min_S1 min_S3]
%           maxstrain is [max_VM max_E1 max_E3]
%           minstrain is [min_VM min_E1 min_E3]
varnamsh = {'\sigma_{VM} (MPa)', '\sigma_1 (MPa)', ...
    '\sigma_3 (MPa)', '\epsilon_{VM}', '\epsilon_1', ...
    '\epsilon_3', '\deltaFG (mm)','\deltaFG_Z (mm)'};
npat = length(vtrial);

% set up y axis variables, which are essentially a row with each TOMO
% loadstep result listed first followed by TOKA
% first list plate stresses, then strains, then fracture gap closing, doing
% HS 2, 3, 4 for SC3, first for HS=2 ************************HS=2
y = [];
hs = 2; % healing stage
sc = 3; % screw config
yi = 1; % index variable
xof = [0 0.2];
for hs=2:4
for dev=1:2
    %dev = 1;% device, 1=TOMO, 2=TOKA
    for pat=1:npat
        if isempty(vtrial(pat).dev) || isempty(vtrial(pat).dev(dev).sc) || length(vtrial(pat).dev(dev).sc(sc).hs) < hs
            % skip this patient, no data
            steps = ls1:ls2;
            y1 =yi+(ls2-ls1);
            x(yi:y1)=steps+xof(dev);
            g(yi:y1)=dev;
            p(yi:y1)=pat;
            y(yi:y1)=nan(1,length(steps));
            yi =y1+1;
        else
            % go through each loadstep
            nsteps = length(vtrial(pat).dev(dev).sc(sc).hs(hs).lstep);
            for lstep=1:nsteps
                switch typ
                    case 1 % plate Von Mises Stress
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(1);
                        else
                            y(yi) = NaN;
                        end
                    case 2 % plate S1 max
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(2);
                        else
                            y(yi) = NaN;
                        end
                    case 3 % plate S3 min
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).minstress(3);
                        else
                            y(yi) = NaN;
                        end
                    case 4 % bone Von mises strain
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstrain(1);
                        else
                            y(yi) = NaN;
                        end
                    case 5 % bone E1 max
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstrain(2);
                        else
                            y(yi) = NaN;
                        end
                    case 6 % bone E3 min
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).minstrain(3);
                        else
                            y(yi) = NaN;
                        end
                    case 7 % gap closing
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).frxdisp == 1)
                            y(yi) =  norm( vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp ...
                                - vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp);
                           %if yi>285 && yi<285+15 && hs==2
                           %      str = sprintf('yi:%d Pat:%d Dev:%d step:%d Prox = %10.3g %10.3g %10.3g, Dist = %10.3g %10.3g %10.3g, gap = %10.3g\n', ...
 			   %		yi,pat,dev,lstep,vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp,...
                           %             vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp, y(yi));
			   %	disp(str);
                           % end
                        else
                            y(yi) = NaN;
                        end
                    case 8 % gap closing
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).frxdisp == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp(3) - ...
                            vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp(3);
                        else
                            y(yi) = NaN;
                        end
                end % switch
                x(yi) = lstep+xof(dev);
                g(yi) = dev;
                p(yi) = pat;
                yi=yi+1;
            end
            if nsteps<(ls2-ls1+1)
                missing_steps = nsteps+1:ls2;
                y1 = yi+(ls2-nsteps-1);
                str = sprintf('pat=%d dev=%d hs=%d nsteps=%d yi=%d y1=%d',pat,dev,hs,nsteps,yi,y1);
                %disp(str);
                x(yi:y1)=missing_steps+xof(dev);
                g(yi:y1)=dev;
                p(yi:y1)=pat;
                y(yi:y1)=nan(1,length(missing_steps));
                yi =y1+1;
            end
        end
    end % pat loop
end % dev loop
switch hs
    case 2
        yh2=y'; y = [];
        xh2=x'; x = [];
        gh2=g'; g = [];
        ph2=p'; p = [];
    case 3
        yh3=y'; y = [];
        xh3=x'; x = [];
        gh3=g'; g = [];
        ph3=p'; p = [];
    case 4
        yh4=y'; y = [];
        xh4=x'; x = [];
        gh4=g'; g = [];
        ph4=p'; p = [];
end
yi=1;
        
end %hs loop

aa = [ 0 16 0 3000;
       0 16 0 900;
       0 16 -2500 50;
       0 16 0 0.15;
       0 16 0 0.15;
       0 16 -0.12 0;
       0 16 0 1.6;
       0 16 -0.8 0.5];

% do plotting
% plot for hs=2
subplot(131);
gscatter(xh2,yh2,gh2);
axis(aa(typ,:));
xlabel('Load Step');
ylabel(varnamsh{typ});
legend('TOMO','TOKA');
tstr = [HSC{3}];
title(tstr);

% plot for hs=3
subplot(132);
gscatter(xh3,yh3,gh3);
axis(aa(typ,:));
xlabel('Load Step');
ylabel(varnamsh{typ});
legend('TOMO','TOKA');
tstr = [HSC{4}];
title(tstr);

% plot for hs=4
subplot(133);
gscatter(xh4,yh4,gh4);
axis(aa(typ,:));
xlabel('Load Step');
ylabel(varnamsh{typ});
legend('TOMO','TOKA');
tstr = [HSC{5}];
title(tstr);

% signed rank test
% for each load step
% first create paired step matrices, s
n = length(xh2);
s2 = [ ph2(1:n/2), xh2(1:n/2), yh2(1:n/2), yh2(1+n/2:n)];
for lstep=ls1:ls2
    % find indices of load step
    i=find(s2(:,2)==lstep);
    v = s2(i,:);
    %disp(['Load step:',num2str(lstep),' Size v = ',num2str(size(v))]);
    % find all NaN
    [row, col] = find(isnan(v(:,3:4)));
    ur = unique(row);
    %disp(['Size row = ',num2str(length(ur))]);
    v(ur,:)=[];
    n2(lstep)=size(v,1);
    %disp(['Size v after NaN removed = ',num2str(size(v))]);
    p2(lstep) = signrank(v(:,3),v(:,4));
end

s3 = [ ph3(1:n/2), xh3(1:n/2), yh3(1:n/2), yh3(1+n/2:n)];
for lstep=ls1:ls2
    % find indices of load step
    i=find(s3(:,2)==lstep);
    v = s3(i,:);
    %disp(['Load step:',num2str(lstep),' Size v = ',num2str(size(v))]);
    % find all NaN
    [row, col] = find(isnan(v(:,3:4)));
    ur = unique(row);
    %disp(['Size row = ',num2str(length(ur))]);
    v(ur,:)=[];
    n3(lstep)=size(v,1);
    %disp(['Size v after NaN removed = ',num2str(size(v))]);
    p3(lstep) = signrank(v(:,3),v(:,4));
end

s4 = [ ph4(1:n/2), xh4(1:n/2), yh4(1:n/2), yh4(1+n/2:n)];
for lstep=ls1:ls2
    % find indices of load step
    i=find(s4(:,2)==lstep);
    v = s4(i,:);
    %disp(['Load step:',num2str(lstep),' Size v = ',num2str(size(v))]);
    % find all NaN
    [row, col] = find(isnan(v(:,3:4)));
    ur = unique(row);
    %disp(['Size row = ',num2str(length(ur))]);
    v(ur,:)=[];
    n4(lstep)=size(v,1);
    %disp(['Size v after NaN removed = ',num2str(size(v))]);
    p4(lstep) = signrank(v(:,3),v(:,4));
end

% display results
disp('---Stats-----Paired Signrank----');
disp([varnames{typ},' Screw Config 3']);

S = [ (ls1:ls2)', p2',n2', p3',n3', p4',n4' ];
format('short','g');
TS = array2table(S,...
    'VariableNames',{'LoadStep','HS2_pval','n2','HS3_pval','n3','HS4_pval','n4'})

%figure;
%stackedplot(TS);
 
 
% stats for all load steps considered together
% HS2
[row,col]=find(isnan(s2(:,3:4)));
ur = unique(row);
v = s2;
v(ur,:)=[];
na2 = size(v,1);
p2a = signrank(v(:,3),v(:,4));
% find all values above fatigue_lim, if typ==1, for chi square test
if typ==1
  i = find(v(:,3)>FLIM);
  j = find(v(:,4)>FLIM);
  f11 = ones(size(v(:,3)));
  f12 = ones(size(v(:,4)));
  f11(i) = 2;
  f12(j) = 2;
%  figure(10);
%  plot([f1,f2+0.2],v(:,3:4),'*');
%  legend('TOMO','TOKA');
  n1 = length(v(:,3))-length(i);
  n2 = length(v(:,4))-length(j);
  str1 = sprintf('%s %s %s: %d =<FLIM %d >FLIM',HSC{3},varnames{typ},devname{1},n1,length(i));
  str2 = sprintf('%s %s %s: %d =<FLIM %d >FLIM',HSC{3},varnames{typ},devname{2},n2,length(j));
  disp(str1);
  disp(str2);
  % group activity steps 1-5=1,6-10=2,11-15=3
  act = [];
  for k=1:length(v(:,2))
     if v(k,2) < 6
       act(k) = 1;
     elseif v(k,2) < 11
       act(k) = 2;
     else
       act(k) = 3;
     end
  end
  dlmwrite('hs2.dat',[f11,f12,act']);
  [tbl1,chi21,p1] = crosstab(f11,f12,act)
 dum=input('Enter');
end

a = 1;

if a
figure(3);
subplot(231);
histogram(v(:,3));
tstr = [HSC{3},' ',devname{1}];
title(tstr);
xlabel(varnamsh{typ});
ylabel('N');
subplot(234);
histogram(v(:,4));
tstr = [HSC{3},' ',devname{2}];
title(tstr);
xlabel(varnamsh{typ});
ylabel('N');
drawnow;
end %a

% HS3
[row,col]=find(isnan(s3(:,3:4)));
ur = unique(row);
v = s3;
v(ur,:)=[];
na3 = size(v,1);
p3a = signrank(v(:,3),v(:,4));
% find all values above fatigue_lim, if typ==1, for chi square test
if typ==1
  i = find(v(:,3)>FLIM);
  j = find(v(:,4)>FLIM);
  f21 = ones(size(v(:,3)));
  f22 = ones(size(v(:,4)));
  f21(i) = 2;
  f22(j) = 2;
%  figure(10);
%  plot([f1,f2+0.2],v(:,3:4),'*');
%  legend('TOMO','TOKA');
  n1 = length(v(:,3))-length(i);
  n2 = length(v(:,4))-length(j);
  str1 = sprintf('%s %s %s: %d =<FLIM %d >FLIM',HSC{4},varnames{typ},devname{1},n1,length(i));
  str2 = sprintf('%s %s %s: %d =<FLIM %d >FLIM',HSC{4},varnames{typ},devname{2},n2,length(j));
  disp(str1);
  disp(str2);
  % group activity steps 1-5=1,6-10=2,11-15=3
  act = [];
  for k=1:length(v(:,2))
     if v(k,2) < 6
       act(k) = 1;
     elseif v(k,2) < 11
       act(k) = 2;
     else
       act(k) = 3;
     end
  end
  
  dlmwrite('hs3.dat',[f21,f22,act']);
  [tbl2,chi22,p2] = crosstab(f21,f22,act)
 dum=input('Enter');
end


if a
figure(3);
subplot(232);
histogram(v(:,3));
tstr = [HSC{4},' ',devname{1}];
title(tstr);
xlabel(varnamsh{typ});
ylabel('N');
subplot(235);
histogram(v(:,4));
tstr = [HSC{4},' ',devname{2}];
title(tstr);
xlabel(varnamsh{typ});
ylabel('N');
drawnow;
end %a


% HS4
[row,col]=find(isnan(s4(:,3:4)));
ur = unique(row);
v = s4;
v(ur,:)=[];
na4 = size(v,1);
p4a = signrank(v(:,3),v(:,4));
% find all values above fatigue_lim, if typ==1, for chi square test
if typ==1
  i = find(v(:,3)>FLIM);
  j = find(v(:,4)>FLIM);
  f31 = ones(size(v(:,3)));
  f32 = ones(size(v(:,4)));
  f31(i) = 2;
  f32(j) = 2;
%  figure(10);
%  plot([f1,f2+0.2],v(:,3:4),'*');
%  legend('TOMO','TOKA');
  n1 = length(v(:,3))-length(i);
  n2 = length(v(:,4))-length(j);
  str1 = sprintf('%s %s %s: %d =<FLIM %d >FLIM',HSC{5},varnames{typ},devname{1},n1,length(i));
  str2 = sprintf('%s %s %s: %d =<FLIM %d >FLIM',HSC{5},varnames{typ},devname{2},n2,length(j));
  disp(str1);
  disp(str2);
  % group activity steps 1-5=1,6-10=2,11-15=3
  act = [];
  for k=1:length(v(:,2))
     if v(k,2) < 6
       act(k) = 1;
     elseif v(k,2) < 11
       act(k) = 2;
     else
       act(k) = 3;
     end
  end
  dlmwrite('hs4.dat',[f31,f32,act']);
  [tbl3,chi23,p3] = crosstab(f31,f32,act)
 dum=input('Enter');
end

if a
figure(3);
subplot(233);
histogram(v(:,3));
tstr = [HSC{5},' ',devname{1}];
title(tstr);
xlabel(varnamsh{typ});
ylabel('N');
subplot(236);
histogram(v(:,4));
tstr = [HSC{5},' ',devname{2}];
title(tstr);
xlabel(varnamsh{typ});
ylabel('N');
drawnow;



SA = [(2:4)', [p2a,p3a,p4a]',[na2,na3,na4]'];
TSA = array2table(SA,...
    'VariableNames',{'HealingStage','pval','n'})

figure(4);
subplot(131);
boxplot(yh2,gh2,'Labels',{'TOMO','TOKA'});
ylabel(varnamsh{typ});
tstr = [HSC{3}];
title(tstr);

subplot(132);
boxplot(yh3,gh3,'Labels',{'TOMO','TOKA'});
ylabel(varnamsh{typ});
tstr = [HSC{4}];
title(tstr);

subplot(133);
boxplot(yh4,gh4,'Labels',{'TOMO','TOKA'});
ylabel(varnamsh{typ});
tstr = [HSC{5}];
title(tstr);

end % a

end % END of function


