function  pltvtrial2sc(vtrial,ls1,ls2,typ)
% [x,y,g,p]=
% PLTVTRIAL2SC function to plot data stored in vtrial, version for SC=1 to
% 3
%
% Richie Gill
% Uni of Bath
% July 2019

% Establish x axis plotting variables and names of variables on y axis
devname={'TOMO';'TOKA'};
% set default loadsteps to be from 1 to 15
if nargin<3
    ls1 = 1;
    ls2 = 15;
    typ = 1;
end

if isempty(ls1)
    ls1 = 1;
end

if isempty(ls2)
    ls2 = 15;
end

%define fatigue limit
FLIM = 180.0; % MPa


% initialise structure, res, for storing results
HSC = {'H2S1', 'H2S2', 'H2S3', 'H3S3','H4S3'};
% typ = 1 , 2, 3, 4, 5, 6, 7, 8 relates to below variables
varnames = {'Von Mises Stress (MPa)', 'Max Pr Stress (MPa)', ...
    'Min Pr Stress (MPa)', 'Von Mises Strain', 'Max Pr Strain', ...
    'Min Pr Strain', 'Frac. Gap Closing (mm)', 'Vert. Frac. Gap Closing (mm)'};
% note that maxstress is [max_VM max_S1 max_S3]
%           minstress is [min_VM min_S1 min_S3]
%           maxstrain is [max_VM max_E1 max_E3]
%           minstrain is [min_VM min_E1 min_E3]
varnamsh = {'\sigma_{VM} (MPa)', '\sigma_1 (MPa)', ...
    '\sigma_3 (MPa)', '\epsilon_{VM}', '\epsilon_1', ...
    '\epsilon_3', '\deltaFG (mm)','\deltaFG_Z (mm)'};
npat = length(vtrial);

% set up y axis variables, which are essentially a row with each TOMO
% loadstep result listed first followed by TOKA
% first list plate stresses, then strains, then fracture gap closing, doing
% HS 2, 3, 4 for SC3, first for HS=2 ************************HS=2
y = [];
hs = 2; % healing stage
yi = 1; % index variable
xof = [0 0.2];
for sc=1:3
for dev=1:2
    %dev = 1;% device, 1=TOMO, 2=TOKA
    for pat=1:npat
        if isempty(vtrial(pat).dev) || isempty(vtrial(pat).dev(dev).sc) || length(vtrial(pat).dev(dev).sc(sc).hs) < hs
            % skip this patient, no data
            steps = ls1:ls2;
            y1 =yi+(ls2-ls1);
            x(yi:y1)=steps+xof(dev);
            g(yi:y1)=dev;
            p(yi:y1)=pat;
            y(yi:y1)=nan(1,length(steps));
            yi =y1+1;
        else
            % go through each loadstep
            nsteps = length(vtrial(pat).dev(dev).sc(sc).hs(hs).lstep);
            for lstep=1:nsteps
                switch typ
                    case 1 % plate Von Mises Stress
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(1);
                        else
                            y(yi) = NaN;
                        end
                    case 2 % plate S1 max
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(2);
                        else
                            y(yi) = NaN;
                        end
                    case 3 % plate S3 min
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).minstress(3);
                        else
                            y(yi) = NaN;
                        end
                    case 4 % bone Von mises strain
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstrain(1);
                        else
                            y(yi) = NaN;
                        end
                    case 5 % bone E1 max
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstrain(2);
                        else
                            y(yi) = NaN;
                        end
                    case 6 % bone E3 min
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).minstrain(3);
                        else
                            y(yi) = NaN;
                        end
                    case 7 % gap closing
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).frxdisp == 1)
                            y(yi) =  norm( vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp ...
                                - vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp);
                           %if yi>285 && yi<285+15 && hs==2
                           %      str = sprintf('yi:%d Pat:%d Dev:%d step:%d Prox = %10.3g %10.3g %10.3g, Dist = %10.3g %10.3g %10.3g, gap = %10.3g\n', ...
 			   %		yi,pat,dev,lstep,vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp,...
                           %             vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp, y(yi));
			   %	disp(str);
                           % end
                        else
                            y(yi) = NaN;
                        end
                    case 8 % gap closing
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).frxdisp == 1)
                            y(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp(3) - ...
                            vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp(3);
                        else
                            y(yi) = NaN;
                        end
                end % switch
                x(yi) = lstep+xof(dev);
                g(yi) = dev;
                p(yi) = pat;
                yi=yi+1;
            end
            if nsteps<(ls2-ls1+1)
                missing_steps = nsteps+1:ls2;
                y1 = yi+(ls2-nsteps-1);
                str = sprintf('pat=%d dev=%d hs=%d nsteps=%d yi=%d y1=%d',pat,dev,hs,nsteps,yi,y1);
                %disp(str);
                x(yi:y1)=missing_steps+xof(dev);
                g(yi:y1)=dev;
                p(yi:y1)=pat;
                y(yi:y1)=nan(1,length(missing_steps));
                yi =y1+1;
            end
        end
    end % pat loop
end % dev loop
switch sc
    case 1
        ys1=y'; y = [];
        xs1=x'; x = [];
        gs1=g'; g = [];
        ps1=p'; p = [];
        sc1=ones(size(ys1))*1;
    case 2
        ys2=y'; y = [];
        xs2=x'; x = [];
        gs2=g'; g = [];
        ps2=p'; p = [];
        sc2=ones(size(ys2))*2;
    case 3
        ys3=y'; y = [];
        xs3=x'; x = [];
        gs3=g'; g = [];
        ps3=p'; p = [];
        sc3=ones(size(ys3))*3;
end
yi=1;
        
end %sc loop

 aa = [ 0 16 0 3000;
        0 16 0 900;
        0 16 -2500 50;
        0 16 0 0.15;
        0 16 0 0.15;
        0 16 -0.12 0;
        0 16 0 1.6;
        0 16 -0.8 0.5];

% do plotting
% plot for sc=1
subplot(131);
gscatter(xs1,ys1,gs1);
axis(aa(typ,:));
xlabel('Load Step');
ylabel(varnamsh{typ});
legend('TOMO','TOKA');
tstr = [HSC{1}];
title(tstr);

% plot for sc = 2
subplot(132);
gscatter(xs2,ys2,gs2);
axis(aa(typ,:));
xlabel('Load Step');
ylabel(varnamsh{typ});
legend('TOMO','TOKA');
tstr = [HSC{2}];
title(tstr);

% plot for sc=3
subplot(133);
gscatter(xs3,ys3,gs3);
axis(aa(typ,:));
xlabel('Load Step');
ylabel(varnamsh{typ});
legend('TOMO','TOKA');
tstr = [HSC{3}];
title(tstr);

aret=0;
if aret
    return
end


% now concatinate vectors to create one response vector Y, and three group
% vectors, D=device(1 or 2), L=loadstep, H=healing stage
Y = [ys1; ys2; ys3]; % response vector, i.e. key variable such as Von Mises Stress
D = [gs1; gs2; gs3]; % device group 1=TOMO 2=TOKA
L = [xs1; xs2; xs3]; % load steps
P = [ps1; ps2; ps3]; % patient
S = [sc1; sc2; sc3]; % screw config group
% recode load steps into activities 1=walk, 2=chair, 3=squat
A = loadstep2act(L);
%summary stats calculation----------------------
% Create activity index for each SC
act1 = loadstep2act(xs1);
act2 = loadstep2act(xs2);
act3 = loadstep2act(xs3);

figure;
alab = {'Act1','Act1','Act2','Act2','Act3','Act3'};
dlab = repmat({'TOMO','ToKa'},1,3);
subplot(131);
boxplot(ys1,[gs1+10*act1],'Labels',{dlab,alab},'colors','rk');
str = sprintf('SC%d %s',1,varnames{typ});
title(str);
sumst1 = sumstat(ys1,gs1,act1,varnames{typ});
dispsumsc(1,sumst1);
subplot(132);
boxplot(ys2,[gs2+10*act2],'Labels',{dlab,alab},'colors','rk');
str = sprintf('SC%d %s',2,varnames{typ});
title(str);
sumst2 = sumstat(ys2,gs2,act2,varnames{typ});
dispsumsc(2,sumst2);
subplot(133);
%boxplot(yh4,[gh4+10*act4],'Labels',boxlabels);
boxplot(ys3,[gs3+10*act3],'Labels',{dlab,alab},'colors','rk');
str = sprintf('SC%d %s',3,varnames{typ});
title(str);
sumst3 = sumstat(ys3,gs3,act3,varnames{typ});
dispsumsc(3,sumst3);

a=1;
if a

% find all NaN's
row = find(isnan(Y));

Y(row)=[];
D(row)=[];
L(row)=[];
P(row)=[];
S(row)=[];
A(row)=[];

%figure; normplot(Y);

%[hy,pp] = lillietest(Y)

%figure;normplot(log10(Y))

%[hyl,ppl] = lillietest(log10(Y))

%p1 = anovan(log10(Y),{D,A,S});

[p,tbl,stats]=anovan(log10(Y),{D,A,S},'model','interaction',...
    'varnames',{'Device','Activity','ScrewConfig'});

%figure; results = multcompare(stats,'Dimension',[1 2 3]);

%figure; normplot(stats.resid);

end % a loop


% output data file for SPSS crosstab analysis

if typ==1
    % first create paired step matrices, s
    n = length(xs1);
    s1 = [ gs1(1:n/2), xs1(1:n/2), ys1(1:n/2), ys1(1+n/2:n), sc1(1:n/2), act1(1:n/2)];
    %check groups
    str = sprintf('SC1 Group 1 mean %f Group 2 mean %f',mean(gs1(1:n/2)),mean(gs1(1+n/2:n)));
    disp(str);
    % first create paired step matrices, s
    n = length(xs2);
    s2 = [ gs2(1:n/2), xs2(1:n/2), ys2(1:n/2), ys2(1+n/2:n), sc2(1:n/2), act2(1:n/2)];
    %check groups
    str = sprintf('SC2 Group 1 mean %f Group 2 mean %f',mean(gs2(1:n/2)),mean(gs2(1+n/2:n)));
    disp(str);
    % first create paired step matrices, s
    n = length(xs3);
    s3 = [ gs3(1:n/2), xs3(1:n/2), ys3(1:n/2), ys3(1+n/2:n), sc3(1:n/2), act3(1:n/2)];
    %check groups
    str = sprintf('SC3 Group 1 mean %f Group 2 mean %f',mean(gs3(1:n/2)),mean(gs3(1+n/2:n)));
    disp(str);
    
    ss = [s1;s2;s3];
    
    
    [row,col]=find(isnan(ss(:,3:4)));
    ur = unique(row);
    v = ss;
    v(ur,:)=[];
    i = find(v(:,3)>FLIM);
    j = find(v(:,4)>FLIM);
    f11 = ones(size(v(:,3)));
    f12 = ones(size(v(:,4)));
    f11(i) = 2;
    f12(j) = 2;
    n1 = length(v(:,3))-length(i);
    n2 = length(v(:,4))-length(j);
    str1 = sprintf('%s %s %s: %d =<FLIM %d >FLIM',HSC{1},varnames{typ},devname{1},n1,length(i));
    str2 = sprintf('%s %s %s: %d =<FLIM %d >FLIM',HSC{1},varnames{typ},devname{2},n2,length(j));
    disp(str1);
    disp(str2);
    dlmwrite('sc_flim.dat',[f11,f12,v(:,5:6)]);
    
end %write data file
  
end % END of function


