function  stats_vtrial(vtrial)
% 
% STATS_VTRIAL function to extract data, calc differences to account for pairing
%
% p = stats_vtrial(vtrial)
%
% Richie Gill
% Uni of Bath
% Jan 2020

% Establish x axis plotting variables and names of variables on y axis
devname={'TOMO';'TOKA'};
% set default loadsteps to be from 1 to 15
ls1 = 1;
ls2 = 15;

%define fatigue limit
FLIM = 180.0; % MPa

% initialise structure, res, for storing results
HSC = {'H2S1', 'H2S2', 'H2S3', 'H3S3','H4S3'};
% typ = 1 , 2, 3, 4, 5, 6, 7, 8 relates to below variables
varnames = {'Von Mises Stress (MPa)', 'Max Pr Stress (MPa)', ...
    'Min Pr Stress (MPa)', 'Von Mises Strain', 'Max Pr Strain', ...
    'Min Pr Strain', 'IFM (mm)', 'Vert. IFM (mm)'};
% note that maxstress is [max_VM max_S1 max_S3]
%           minstress is [min_VM min_S1 min_S3]
%           maxstrain is [max_VM max_E1 max_E3]
%           minstrain is [min_VM min_E1 min_E3]
varnamsh = {'\sigma_{VM} (MPa)', '\sigma_1 (MPa)', ...
    '\sigma_3 (MPa)', '\epsilon_{VM}', '\epsilon_1', ...
    '\epsilon_3', '\deltaFG (mm)','\deltaFG_Z (mm)'};
npat = length(vtrial);

% set up y axis variables, which are essentially a row with each TOMO
% loadstep result listed first followed by TOKA
% first list plate stresses, then strains, then fracture gap closing, doing
% HS 2, 3, 4 for SC3, first for HS=2 ************************HS=2
xof = [0 0.2];
sc = 3; % screw config
for hs=2:4
y = [];
vms = []; % von mises stress
vme = []; % von mises strain, epsilon
fgc = []; % fracture gap closing
yi = 1; % index variable
for dev=1:2
    %dev = 1;% device, 1=TOMO, 2=TOKA
    for pat=1:npat
        if isempty(vtrial(pat).dev) || isempty(vtrial(pat).dev(dev).sc) || length(vtrial(pat).dev(dev).sc(sc).hs) < hs
            % skip this patient, no data
            steps = ls1:ls2;
            y1 =yi+(ls2-ls1);
            x(yi:y1)=steps+xof(dev);
            g(yi:y1)=dev;
            p(yi:y1)=pat;
            vms(yi:y1)=nan(1,length(steps));
            vme(yi:y1)=nan(1,length(steps));
            fgc(yi:y1)=nan(1,length(steps));
            y(yi:y1)=nan(1,length(steps));
            yi =y1+1;
        else
            % go through each loadstep
            nsteps = length(vtrial(pat).dev(dev).sc(sc).hs(hs).lstep);
            for lstep=1:nsteps
                % plate Von Mises Stress
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).pstress == 1)
                            vms(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstress(1);
                        else
                            vms(yi) = NaN;
                        end
                % bone Von mises strain
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).hstrain == 1)
                            vme(yi) = vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).maxstrain(1);
                        else
                            vme(yi) = NaN;
                        end
                 % gap closing
                        if (vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).frxdisp == 1)
                            fgc(yi) =  norm( vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp ...
                                - vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp);
                           %if yi>285 && yi<285+15 && hs==2
                           %      str = sprintf('yi:%d Pat:%d Dev:%d step:%d Prox = %10.3g %10.3g %10.3g, Dist = %10.3g %10.3g %10.3g, gap = %10.3g\n', ...
 			   %		yi,pat,dev,lstep,vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).proxdisp,...
                           %             vtrial(pat).dev(dev).sc(sc).hs(hs).lstep(lstep).distdisp, y(yi));
			   %	disp(str);
                           % end
                        else
                            fgc(yi) = NaN;
                        end
                x(yi) = lstep+xof(dev);
                g(yi) = dev;
                p(yi) = pat;
                yi=yi+1;
            end
            if nsteps<(ls2-ls1+1)
                missing_steps = nsteps+1:ls2;
                y1 = yi+(ls2-nsteps-1);
                str = sprintf('pat=%d dev=%d hs=%d nsteps=%d yi=%d y1=%d',pat,dev,hs,nsteps,yi,y1);
                %disp(str);
                x(yi:y1)=missing_steps+xof(dev);
                g(yi:y1)=dev;
                p(yi:y1)=pat;
                vms(yi:y1)=nan(1,length(missing_steps));
                vme(yi:y1)=nan(1,length(missing_steps));
                fgc(yi:y1)=nan(1,length(missing_steps));
                yi =y1+1;
            end
        end
    end % pat loop
end % dev loop
switch hs
    case 2
        vmsh2=vms'; 
        vmeh2=vme'; 
        fgch2=fgc'; 
        xh2=x'; x = [];
        gh2=g'; g = [];
        ph2=p'; p = [];
        hs2=ones(size(xh2))*2;
    case 3
        vmsh3=vms'; 
        vmeh3=vme'; 
        fgch3=fgc'; 
        %yh3=y'; y = [];
        xh3=x'; x = [];
        gh3=g'; g = [];
        ph3=p'; p = [];
        hs3=ones(size(xh3))*3;
    case 4
        vmsh4=vms'; 
        vmeh4=vme'; 
        fgch4=fgc'; 
        xh4=x'; x = [];
        gh4=g'; g = [];
        ph4=p'; p = [];
        hs4=ones(size(xh4))*4;
end
yi=1;
        
end %hs loop

% check loadsteps, patients and groups all match
n = length(xh2);
outdat = [gh2, ph2, [xh2(1:n/2);xh2(1:n/2)], vmsh2, vmsh3, vmsh4, vmeh2, vmeh3, vmeh4,fgch2,fgch3,fgch4];
csvwrite('vtrial_stress_h2h3h4.csv',outdat);


%ZOOL

% calculate differences between groups by subtracting TOMO results from
% TOKA
% HS2
    n = length(xh2);
    dvmsh2 = vmsh2(1+n/2:n)-vmsh2(1:n/2);
    dvmeh2 = vmeh2(1+n/2:n)-vmeh2(1:n/2);
    dfgch2 = fgch2(1+n/2:n)-fgch2(1:n/2);
% HS3
    n = length(xh3);
    dvmsh3 = vmsh3(1+n/2:n)-vmsh3(1:n/2);
    dvmeh3 = vmeh3(1+n/2:n)-vmeh3(1:n/2);
    dfgch3 = fgch3(1+n/2:n)-fgch3(1:n/2);
% HS4
    n = length(xh4);
    dvmsh4 = vmsh4(1+n/2:n)-vmsh4(1:n/2);
    dvmeh4 = vmeh4(1+n/2:n)-vmeh4(1:n/2);
    dfgch4 = fgch4(1+n/2:n)-fgch4(1:n/2);

%for each activity find mean and 95% CI for vms/vme/fgc
% hs2
sumstat(2,xh2,vmsh2,vmeh2,fgch2);
        
% find how many loadsteps > FLIM   
% HS2
    vmsd1_h2 = rmmissing(vmsh2(1:n/2));
    vmsd2_h2 = rmmissing(vmsh2(1+n/2:n));
    d1_h2_flim = find(vmsd1_h2>FLIM);
    d2_h2_flim = find(vmsd2_h2>FLIM);
    disp(' ');
    ctab_h2 = table([length(vmsd1_h2)-length(d1_h2_flim); length(vmsd2_h2)-length(d2_h2_flim)], ...
        [length(d1_h2_flim); length(d2_h2_flim)], ...
        'VariableNames',{'LessThan_FLIM','Exceeds_FLIM'},'RowNames',{'H2:TOMO','H2:TOKA'});
    disp(ctab_h2);
    [h,p,stats] = fishertest(ctab_h2);
   % mcnemar(table2array(ctab_h2)');

% hs3
sumstat(3,xh3,vmsh3,vmeh3,fgch3);

% HS3
    vmsd1_h3 = rmmissing(vmsh3(1:n/2));
    vmsd2_h3 = rmmissing(vmsh3(1+n/2:n));
    d1_h3_flim = find(vmsd1_h3>FLIM);
    d2_h3_flim = find(vmsd2_h3>FLIM);
    ctab_h3 = table([length(vmsd1_h3)-length(d1_h3_flim); length(vmsd2_h3)-length(d2_h3_flim)], ...
        [length(d1_h3_flim); length(d2_h3_flim)], ...
        'VariableNames',{'LessThan_FLIM','Exceeds_FLIM'},'RowNames',{'H3:TOMO','H3:TOKA'});
    disp(ctab_h3);
    [h,p,stats] = fishertest(ctab_h3);
   % mcnemar(table2array(ctab_h3));

% hs4
sumstat(4,xh4,vmsh4,vmeh4,fgch4);

% HS4
    vmsd1_h4 = rmmissing(vmsh4(1:n/2));
    vmsd2_h4 = rmmissing(vmsh4(1+n/2:n));
    d1_h4_flim = find(vmsd1_h4>FLIM);
    d2_h4_flim = find(vmsd2_h4>FLIM);
    ctab_h4 = table([length(vmsd1_h4)-length(d1_h4_flim); length(vmsd2_h4)-length(d2_h4_flim)], ...
        [length(d1_h4_flim); length(d2_h4_flim)], ...
        'VariableNames',{'LessThan_FLIM','Exceeds_FLIM'},'RowNames',{'H4:TOMO','H4:TOKA'});
    disp(ctab_h4);
    [h,p,stats] = fishertest(ctab_h4);
   % mcnemar(table2array(ctab_h4));
    
% now concatinate vectors to create response vectors for stress, strain & fgc and three group
% vectors, D=device(1 or 2), L=loadstep, H=healing stage
dVMS = [dvmsh2; dvmsh3; dvmsh4]; % Von Mises Stress
dVME = [dvmeh2; dvmeh3; dvmeh4]; % Von Mises Strain
dFGC = [dfgch2; dfgch3; dfgch4]; % Von Mises Stress


[xx2,yy2,neg2,pos2,pv2] = mean95ci(dvmsh2,xh2(1:n/2),2);
[xx3,yy3,neg3,pos3,pv3] = mean95ci(dvmsh3,xh3(1:n/2),3);
[xx4,yy4,neg4,pos4,pv4] = mean95ci(dvmsh4,xh4(1:n/2),4);

a=0;

if a
figure;
subplot(131);
errorbar([xx2,xx3,xx4],[yy2,yy3,yy4],[neg2,neg3,neg4],...
    [pos2,pos3,pos4],'o');
aa=axis;
axis([1.5 4.5 aa(3:4)]);
xlabel('Healing Stage');
ylabel('\delta VMS (MPa)');

[xx2,yy2,neg2,pos2,pv2] = mean95ci(dvmeh2,xh2(1:n/2),2);
[xx3,yy3,neg3,pos3,pv3] = mean95ci(dvmeh3,xh3(1:n/2),3);
[xx4,yy4,neg4,pos4,pv4] = mean95ci(dvmeh4,xh4(1:n/2),4);

subplot(132);
errorbar([xx2,xx3,xx4],[yy2,yy3,yy4],[neg2,neg3,neg4],...
    [pos2,pos3,pos4],'o');
aa=axis;
axis([1.5 4.5 aa(3:4)]);
xlabel('Healing Stage');
ylabel('\delta VME');

[xx2,yy2,neg2,pos2,pv2] = mean95ci(dfgch2,xh2(1:n/2),2);
[xx3,yy3,neg3,pos3,pv3] = mean95ci(dfgch3,xh3(1:n/2),3);
[xx4,yy4,neg4,pos4,pv4] = mean95ci(dfgch4,xh4(1:n/2),4);

subplot(133);
errorbar([xx2,xx3,xx4],[yy2,yy3,yy4],[neg2,neg3,neg4],...
    [pos2,pos3,pos4],'o');
aa=axis;
axis([1.5 4.5 aa(3:4)]);
xlabel('Healing Stage');
ylabel('\delta FGC (mm)');

end % a loop

a=1;
if a

% plot at each load step
[pvms] = ActHSmean95ci(dvmsh2,dvmsh3,dvmsh4,xh2(1:n/2),'\delta VMS','MPa');
[pvme] = ActHSmean95ci(dvmeh2,dvmeh3,dvmeh4,xh2(1:n/2),'\delta VME',[]);
[pfgc] = ActHSmean95ci(dfgch2,dfgch3,dfgch4,xh2(1:n/2),'\delta FGC','mm');

end

% find means and confidence intervals
mdvms2 = nanmean(dvmsh2);
[H2,P2,CI2]=ttest(dvmsh2);
mdvms3 = nanmean(dvmsh3);
[H3,P3,CI3]=ttest(dvmsh3);
mdvms4 = nanmean(dvmsh4);
[H4,P4,CI4]=ttest(dvmsh4);

%D = [gh2(; gh3; gh4]; % device group 1=TOMO 2=TOKA
L = [xh2(1:n/2); xh3(1:n/2); xh4(1:n/2)]; % load steps
P = [ph2(1:n/2); ph3(1:n/2); ph4(1:n/2)]; % patient
H = [hs2(1:n/2); hs3(1:n/2); hs4(1:n/2)]; % healing stage group
% recode load steps into activities 1=walk, 2=chair, 3=squat
A = loadstep2act(L);
%summary stats calculation----------------------
% Create activity index for each HS
act2 = loadstep2act(xh2);
act3 = loadstep2act(xh3);
act4 = loadstep2act(xh4);

%ZOOL
a=0;

if a
figure;
subplot(131);
blab = {'HS2','HS3','HS4'};
boxplot(dVMS,H,'Labels',blab);
title('\deltaVonMisesStress (MPa)');

subplot(132);
boxplot(dVME,H,'Labels',blab);
title('\deltaVonMisesStrain');

subplot(133);
boxplot(dFGC,H,'Labels',blab);
title('\deltaFracGapClosing (mm)');


alab = {'Act1','Act1','Act2','Act2','Act3','Act3'};
dlab = repmat({'TOMO','ToKa'},1,3);
subplot(131);
%boxplot(yh2,[gh2+10*act2],'Labels',boxlabels);
boxplot(yh2,[gh2+10*act2],'Labels',{dlab,alab},'colors','rk');
str = sprintf('HS%d %s',2,varnames{typ});
title(str);
sumst2 = sumstat(yh2,gh2,act2,varnames{typ});
dispsum(2,sumst2);
subplot(132);
%boxplot(yh3,[gh3+10*act3],'Labels',boxlabels);
boxplot(yh3,[gh3+10*act3],'Labels',{dlab,alab},'colors','rk');
str = sprintf('HS%d %s',3,varnames{typ});
title(str);
sumst3 = sumstat(yh3,gh3,act3,varnames{typ});
dispsum(3,sumst3);
subplot(133);
%boxplot(yh4,[gh4+10*act4],'Labels',boxlabels);
boxplot(yh4,[gh4+10*act4],'Labels',{dlab,alab},'colors','rk');
str = sprintf('HS%d %s',4,varnames{typ});
title(str);
sumst4 = sumstat(yh4,gh4,act4,varnames{typ});
dispsum(4,sumst4);

end % a loop

% ZOOL
%a=0;
if a

% find all NaN's
row = find(isnan(Y));

Y(row)=[];
D(row)=[];
L(row)=[];
P(row)=[];
H(row)=[];
A(row)=[];

figure; normplot(Y);

%[hy,pp] = lillietest(Y)

figure;normplot(log10(Y))

%[hyl,ppl] = lillietest(log10(Y))

p1 = anovan(log10(Y),{D,A,H});

[p,tbl,stats]=anovan(log10(Y),{D,A,H},'model','interaction',...
    'varnames',{'Device','Activity','HealingStage'});

figure; results = multcompare(stats,'Dimension',[1 2 3]);

figure; normplot(stats.resid);

end % a loop
%zool
a=0;
if a

if typ==1 || typ==4 || typ==7
    % first create paired step matrices, s
    n = length(xh2);
    h2 = [ gh2(1:n/2), xh2(1:n/2), yh2(1:n/2), yh2(1+n/2:n), hs2(1:n/2), act2(1:n/2), ph2(1:n/2)];
    % first create paired step matrices, s
    n = length(xh3);
    h3 = [ gh3(1:n/2), xh3(1:n/2), yh3(1:n/2), yh3(1+n/2:n), hs3(1:n/2), act3(1:n/2), ph3(1:n/2)];
    % first create paired step matrices, s
    n = length(xh4);
    h4 = [ gh4(1:n/2), xh4(1:n/2), yh4(1:n/2), yh4(1+n/2:n), hs4(1:n/2), act4(1:n/2), ph4(1:n/2)];

    % do correlation plots
    figure;
    subplot(311);
    gscatter(h2(:,3),h2(:,4),h2(:,6));
    legend({'ACT1','ACT2','ACT3'});
    xlabel('TOMO VM Stress');
    ylabel('TOKA VM Stress');
    title('HS2');
    axis equal;
    subplot(312);
    gscatter(h3(:,3),h3(:,4),h3(:,6));
    legend({'ACT1','ACT2','ACT3'});
    xlabel('TOMO VM Stress');
    ylabel('TOKA VM Stress');
    title('HS3');
    axis equal;
    subplot(313);
    gscatter(h4(:,3),h4(:,4),h4(:,6));
    legend({'ACT1','ACT2','ACT3'});
    xlabel('TOMO VM Stress');
    ylabel('TOKA VM Stress');
    title('HS4');
    axis equal;
    
    [row,col]=find(isnan(h2(:,3:4)));
    ur = unique(row);
    v2 = h2;
    v2(ur,:)=[];
    disp('HS2');
    [c2,p2,c2l,c2u]=corrcoef(v2(:,3:4));
    str = sprintf('Pearson''s = %12.3g p = %12.3g',c2(1,2),p2(1,2));
    disp(str);
    [rho,pp]=corr(v2(:,3:4),'Type','Spearman');
    str = sprintf('Spearman''s rho = %12.3g p = %12.3g',rho(1,2),pp(1,2));
    disp(str);
    rvhs2 = rho(1,2);
    
    [row,col]=find(isnan(h3(:,3:4)));
    ur = unique(row);
    v3 = h3;
    v3(ur,:)=[];
    disp('HS3');
    [c3,p3,c3l,c3u]=corrcoef(v3(:,3:4));
    str = sprintf('Pearson''s = %12.3g p = %12.3g',c3(1,2),p3(1,2));
    disp(str);
    [rho,pp]=corr(v3(:,3:4),'Type','Spearman');
    str = sprintf('Spearman''s rho = %12.3g p = %12.3g',rho(1,2),pp(1,2));
    disp(str);
    rvhs3 = rho(1,2);

    [row,col]=find(isnan(h4(:,3:4)));
    ur = unique(row);
    v4 = h4;
    v4(ur,:)=[];
    disp('HS4');
    [c4,p4,c4l,c4u]=corrcoef(v4(:,3:4));
    str = sprintf('Pearson''s = %12.3g p = %12.3g',c4(1,2),p4(1,2));
    disp(str);
    [rho,pp]=corr(v4(:,3:4),'Type','Spearman');
    str = sprintf('Spearman''s rho = %12.3g p = %12.3g',rho(1,2),pp(1,2));
    disp(str);
    rvhs4 = rho(1,2);
    
    str = sprintf('Av. Spearman''s rho = %12.3g',mean([rvhs2 rvhs3 rvhs4]));
    disp(str);


    ss = [h2;h3;h4];
    % write data out to data file
    dlmwrite('tmp.dat',ss(:,2:7));
    fid = fopen('tmp.dat','rt') ;
    XD = fread(fid) ;
    fclose(fid) ;
    XD = char(XD.') ;
    % replace string S1 with string S2
    YD = strrep(XD, 'NaN', '') ;
    if typ==1
        fout = 'VMS.dat';
    elseif typ==4
        fout = 'Strain.dat';
    else
        fout = 'Gap.dat';
    end
    fid2 = fopen(fout,'wt') ;
    fwrite(fid2,YD) ;
    fclose (fid2) ;   
    
    if typ==1
    [row,col]=find(isnan(ss(:,3:4)));
    ur = unique(row);
    v = ss;
    v(ur,:)=[];
    i = find(v(:,3)>FLIM);
    j = find(v(:,4)>FLIM);
    f11 = ones(size(v(:,3)));
    f12 = ones(size(v(:,4)));
    f11(i) = 2;
    f12(j) = 2;
    % zool
    dlmwrite('hs_flim.dat',[f11,f12,v(:,5:6)]);
    end %FLIM loop 
   
end %write data file

end % a loop


end % END of function


